<?php

namespace Zeedhi\DataExporter\Utility;

use Zeedhi\Framework\Session\Session;

class ReportInfoManager {
    
    /** @const KEY_PREFIX Prefix to save the report data on the session. */
    const KEY_PREFIX = "DATAEXPORTER";
    /** @var Session Session where will be saved the report info. */
    var $session;
    
    /**
     * Constructor.
     *
     * @param Session $session Service to maintain the data on the session.
     */
    public function __construct(Session $session) {
        $this->session = $session;

        if (!$this->session->isStarted()) {
			$this->session->start();
		}
    }

    /**
     * Save the file data on the session.
     *
     * Generate a key to save the file and returns it.
     *
     * @param string $fileName File name to be saved on the session.
     * @return string Key of the file info.
     */
    public function save($fileName){
        $key = uniqid($this::KEY_PREFIX);
        $this->session->set($key, $fileName);
        return $key;
    }

    /**
     * Return the info of the file with the given key.
     *
     * Return the info of the file with the given key removing it from the session.
     *
     * @param string $key Key of the desired file info.
     *
     * @return array Report info.
     */    
    public function getReportInfo($key){
        $data = $this->session->remove($key);
        return $data;
    }

}